@@ -357,7 +357,7 @@ SaffirePro26::SaffirePro26EAP::MonitorSection::MonitorSection(Dice::Focusrite::F
 }
 
 SaffirePro26::SaffirePro26( DeviceManager& d,
-                            std::auto_ptr<ConfigRom>( configRom ))
+                            ffado_smartptr<ConfigRom>( configRom ))
     : Dice::Device(d , configRom)
 {
     debugOutput(DEBUG_LEVEL_VERBOSE, "Created Dice::Focusrite::SaffirePro26 (NodeID %d)\n",
