@@ -34,17 +34,18 @@
 
 #include <iostream>
 #include <sstream>
+#include <unistd.h>
 
 #include <assert.h>
 
 IMPL_DEBUG_MODULE( FFADODevice, FFADODevice, DEBUG_LEVEL_NORMAL );
 
-FFADODevice::FFADODevice( DeviceManager& d, std::auto_ptr<ConfigRom>( configRom ) )
+FFADODevice::FFADODevice( DeviceManager& d, ffado_smartptr<ConfigRom>( configRom ) )
     : Control::Container(&d)
     , m_pConfigRom( configRom )
     , m_pDeviceManager( d )
 {
-    addOption(Util::OptionContainer::Option("id",std::string("dev?")));
+    addOption(Util::OptionContainer::Option("id",m_pConfigRom->getGuidString()));
 
     std::ostringstream nodestr;
     nodestr << "node" << getConfigRom().getNodeId();
@@ -98,7 +99,7 @@ FFADODevice::~FFADODevice()
 }
 
 FFADODevice *
-FFADODevice::createDevice(std::auto_ptr<ConfigRom>( x ))
+FFADODevice::createDevice(ffado_smartptr<ConfigRom>( x ))
 {
     // re-implement this!!
     assert(0);
@@ -165,20 +166,6 @@ FFADODevice::getStreamingState()
     return eSS_Idle;
 }
 
-bool
-FFADODevice::setId( unsigned int id)
-{
-    Util::MutexLockHelper lock(m_DeviceMutex);
-    bool retval;
-    // FIXME: decent ID system nescessary
-    std::ostringstream idstr;
-    idstr << "dev" << id;
-    debugOutput( DEBUG_LEVEL_VERBOSE, "Set id to %s...\n", idstr.str().c_str());
-
-    retval=setOption("id",idstr.str());
-    return retval;
-}
-
 bool
 FFADODevice::setNickname( std::string name)
 {
