@@ -20,7 +20,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-#include "config.h"
+
 
 #include "AmdtpReceiveStreamProcessor.h"
 #include "AmdtpPort.h"
@@ -34,6 +34,9 @@
 #include "libutil/ByteSwap.h"
 #include <assert.h>
 #include "libutil/SystemTimeSource.h"
+#include <cstring>
+
+#define unlikely(x) __builtin_expect((x),0)
 
 namespace Streaming {
 
@@ -44,6 +47,8 @@ AmdtpReceiveStreamProcessor::AmdtpReceiveStreamProcessor(FFADODevice &parent, in
     , m_dimension( dimension )
     , m_nb_audio_ports( 0 )
     , m_nb_midi_ports( 0 )
+    , mb_head( 0 )
+    , mb_tail( 0 )
 {}
 
 unsigned int
@@ -133,7 +138,68 @@ AmdtpReceiveStreamProcessor::processPacketData(unsigned char *data, unsigned int
     struct iec61883_packet *packet = (struct iec61883_packet *) data;
     assert(packet);
 
-    unsigned int nevents=((length / sizeof (quadlet_t)) - 2)/packet->dbs;
+    /*
+    Euan de Kock <euan@dekock.net> 8th February 2011
+
+    See Ticket #310
+
+    This is a fix to force the Echo Devices to work at
+    sample rates above 48000 where the ADAT digital channels
+    get multiplexed to handle higher frequencies.
+    At 88200 and 96000 the ADAT channels are reduced to 4,
+    and at 192000 they should be reduced to 2. (I don't have a
+    device capable of 192K to verify this)
+
+    With the Echo devices (5.5 firmware at least), the device does
+    not reduce its channel count when it multiplexes the ADAT data,
+    but the actual packet does contain a reduced set of channels.
+
+    The channels are referred to as Dimensions in the firewire parlance.
+    With an Audiofire Pre8, we typically receive 17 channels of data at
+    44100 and 48000, being 8 Analog, 8 Digital and 1 MIDI. When we switch
+    to 88200 or 96000 the ADAT (Digital) channel count is reduced to four,
+    giving a total channel count (dimension) of 13. However Echo still
+    reports the DBS parameter as being 17.
+
+    To get around this, I don't bother using the DBS value at all. We know
+    that the FDF is a reliable value for AM824 packets (type 0  to 7), so
+    we can just use the FDF field to directly infer the size of each channel
+    or dimension - 8, 16 or 32 Quadwords respectively for 41/48K, 88/96K and 192K.
+
+    We set nevents directly to this for all AM824 packets directly, and do
+    the standard calculation for any non-standard types.
+
+    This is actually slightly less work than doing the calculation directly
+    and should be portable across all devices that send AM824 data.
+    */
+    unsigned int nevents;
+
+    switch(packet->fdf)
+        {
+        case 0x00:
+        case 0x01:
+        case 0x02:
+	    // 8Q = 32B
+            nevents=8;
+	    break;
+        case 0x03:
+        case 0x04:
+	    // 16Q = 64B
+            nevents=16;
+	    break;
+        case 0x05:
+        case 0x06:
+	    // 32Q = 128B
+            nevents=32;
+	    break;
+        default:
+            nevents=((length / sizeof (quadlet_t)) - 2)/packet->dbs;
+	    break;
+        }
+
+    debugOutput(DEBUG_LEVEL_VERY_VERBOSE,
+                "packet->dbs %d calculated dbs %d packet->fdf %02X nevents %d\n",
+                packet->dbs, (length - 8)/nevents, packet->fdf, nevents);
 
     // we have to keep in mind that there are also
     // some packets buffered by the ISO layer,
@@ -142,7 +208,7 @@ AmdtpReceiveStreamProcessor::processPacketData(unsigned char *data, unsigned int
     // frames, meaning that we might receive
     // this packet x*syt_interval*ticks_per_frame
     // later than expected (the real receive time)
-    #ifdef DEBUG
+    #if DEBUG_EXTREME_ENABLE
     static int64_t last_t = Util::SystemTimeSource::getCurrentTime();
     int64_t now_t = Util::SystemTimeSource::getCurrentTime();
     if(isRunning()) {
@@ -154,7 +220,9 @@ AmdtpReceiveStreamProcessor::processPacketData(unsigned char *data, unsigned int
                            m_last_timestamp, now_t-last_t, m_data_buffer->getBufferFill());*/
     }
     last_t = now_t;
+    #endif
 
+    #ifdef DEBUG
     // check whether nevents is a multiple of 8.
     if (nevents & 0x7) {
         debugError("Invalid nevents value for AMDTP (%u)\n", nevents);
@@ -222,7 +290,9 @@ AmdtpReceiveStreamProcessor::decodeAudioPortsInt24(quadlet_t *data,
     for (i = 0; i < m_nb_audio_ports; i++) {
         struct _MBLA_port_cache &p = m_audio_ports.at(i);
         target_event = (quadlet_t *)(data + i);
+#ifdef DEBUG
         assert(nevents + offset <= p.buffer_size );
+#endif
 
         if(p.buffer && p.enabled) {
             quadlet_t *buffer = (quadlet_t *)(p.buffer);
@@ -256,7 +326,9 @@ AmdtpReceiveStreamProcessor::decodeAudioPortsFloat(quadlet_t *data,
     for (i = 0; i < m_nb_audio_ports; i++) {
         struct _MBLA_port_cache &p = m_audio_ports.at(i);
         target_event = (quadlet_t *)(data + i);
+#ifdef DEBUG
         assert(nevents + offset <= p.buffer_size );
+#endif
 
         if(p.buffer && p.enabled) {
             float *buffer = (float *)(p.buffer);
@@ -293,7 +365,9 @@ AmdtpReceiveStreamProcessor::decodeAudioPortsInt24(quadlet_t *data,
     for (i = 0; i < m_nb_audio_ports; i++) {
         struct _MBLA_port_cache &p = m_audio_ports.at(i);
         target_event = (quadlet_t *)(data + i);
+#ifdef DEBUG
         assert(nevents + offset <= p.buffer_size );
+#endif
 
         if(p.buffer && p.enabled) {
             quadlet_t *buffer = (quadlet_t *)(p.buffer);
@@ -327,7 +401,9 @@ AmdtpReceiveStreamProcessor::decodeAudioPortsFloat(quadlet_t *data,
     for (i = 0; i < m_nb_audio_ports; i++) {
         struct _MBLA_port_cache &p = m_audio_ports.at(i);
         target_event = (quadlet_t *)(data + i);
+#ifdef DEBUG
         assert(nevents + offset <= p.buffer_size );
+#endif
 
         if(p.buffer && p.enabled) {
             float *buffer = (float *)(p.buffer);
@@ -367,25 +443,46 @@ AmdtpReceiveStreamProcessor::decodeMidiPorts(quadlet_t *data,
         if (p.buffer && p.enabled) { 
             uint32_t *buffer = (quadlet_t *)(p.buffer);
             buffer += offset;
-            for (j = p.location;j < nevents; j += 8) {
+
+            /* clear output (to jackd) buffer for MIDI data */
+            memset (buffer, 0, nevents*sizeof(*buffer));
+
+            for (j = 0; j < nevents; j += 1) {
                 target_event = (quadlet_t *) (data + ((j * m_dimension) + p.position));
                 sample_int = CondSwapFromBus32(*target_event);
 
                 // FIXME: this assumes that 2X and 3X speed isn't used,
                 // because only the 1X slot is put into the ringbuffer
-                if(IEC61883_AM824_HAS_LABEL(sample_int, IEC61883_AM824_LABEL_MIDI_1X)) {
+                if(unlikely(IEC61883_AM824_HAS_LABEL(sample_int, IEC61883_AM824_LABEL_MIDI_1X))) {
                     sample_int=(sample_int >> 16) & 0x000000FF;
                     sample_int |= 0x01000000; // flag that there is a midi event present
-                    *buffer = sample_int;
-                    debugOutputExtreme(DEBUG_LEVEL_VERBOSE, "(%p) MIDI [%d]: %08X\n", this, i, sample_int);
-                } else if(IEC61883_AM824_HAS_LABEL(sample_int, IEC61883_AM824_LABEL_MIDI_2X)
-                       || IEC61883_AM824_HAS_LABEL(sample_int, IEC61883_AM824_LABEL_MIDI_3X) ) {
-                    debugOutput(DEBUG_LEVEL_VERBOSE, "Midi mode %X not supported.\n", IEC61883_AM824_GET_LABEL(sample_int));
-                } else {
-                    // make sure no event is received
-                    *buffer = 0;
+                    midibuffer[mb_head++] = sample_int;
+                    mb_head &= RX_MIDIBUFFER_SIZE-1;
+                    if (unlikely(mb_head == mb_tail)) {
+                        debugWarning("AMDTP rx MIDI buffer overflow\n");
+                        /* Dump oldest byte.  This overflow can only happen if the
+                         * rate coming in from the hardware MIDI port grossly
+                         * exceeds the official MIDI baud rate of 31250 bps, so it
+                         * should never occur in practice.
+                         */
+                        mb_tail = (mb_tail + 1) & (RX_MIDIBUFFER_SIZE-1);
+                    }
+
+                    debugOutputExtreme(DEBUG_LEVEL_VERBOSE, "(%p) MIDI [%d]: %08X\n", this,
+                            i, sample_int);
+                } else if(unlikely((IEC61883_AM824_HAS_LABEL(sample_int, IEC61883_AM824_LABEL_MIDI_2X)
+                        || IEC61883_AM824_HAS_LABEL(sample_int, IEC61883_AM824_LABEL_MIDI_3X) ))) {
+                    debugOutput(DEBUG_LEVEL_VERBOSE, "Midi mode %X not supported.\n",
+                            IEC61883_AM824_GET_LABEL(sample_int));
+                }
+                /* Write to the buffer if we're at an 8-sample boundary */
+                if (unlikely(0 == j % 8)) {
+                    if (mb_head != mb_tail) {
+                        *buffer = midibuffer[mb_tail++];
+                        mb_tail &= RX_MIDIBUFFER_SIZE-1;
+                    }
+                    buffer += 8;
                 }
-                buffer+=8;
             }
         }
     }
@@ -494,6 +591,7 @@ next_index:
     return true;
 }
 
+//FIXME: DRY. Needs to be refactored with AmdtpTransmitStreamProcessor
 void
 AmdtpReceiveStreamProcessor::updatePortCache() {
     unsigned int idx;
@@ -502,12 +600,18 @@ AmdtpReceiveStreamProcessor::updatePortCache() {
         AmdtpAudioPort *port = p.port;
         p.buffer = port->getBufferAddress();
         p.enabled = !port->isDisabled();
+#ifdef DEBUG
+	p.buffer_size = port->getBufferSize();
+#endif
     }
     for (idx = 0; idx < m_nb_midi_ports; idx++) {
         struct _MIDI_port_cache& p = m_midi_ports.at(idx);
         AmdtpMidiPort *port = p.port;
         p.buffer = port->getBufferAddress();
         p.enabled = !port->isDisabled();
+#ifdef DEBUG
+	p.buffer_size = port->getBufferSize();
+#endif
     }
 }
 
