@@ -25,7 +25,7 @@
 #define _FFADO_UTIL_CONFIGURATION_
 
 #include "debugmodule/debugmodule.h"
-#include "external/libconfig/libconfigpp.h"
+#include "libconfig.h++"
 
 #include <vector>
 
@@ -41,12 +41,19 @@ namespace Util {
 class Configuration {
 public:
     // driver ID's to be used in the config file
+    // Note: When changing this enum, please update convertDriver code as well!
     enum eDrivers {
-        eD_Unknown = 0,
-        eD_BeBoB = 1,
-        eD_FireWorks = 2,
-        eD_GenericAVC = 3,
-        eD_MOTU = 10,
+        eD_Unknown     = 0,
+        eD_BeBoB       = 1,
+        eD_FireWorks   = 2,
+        eD_GenericAVC  = 3,
+        eD_Oxford      = 4,
+        eD_MOTU        = 10,
+        eD_DICE        = 20,
+        eD_MetricHalo  = 30,
+        eD_RME         = 40,
+        eD_Bounce      = 50,
+        eD_Digidesign  = 60,
     };
 
     // the modes a config file can have
@@ -152,6 +159,8 @@ private:
 
     int findFileName(std::string s);
 
+    unsigned int convertDriver(const std::string & driver) const;
+    
     // important: keep 1-1 mapping for these two!
     // cannot use map since we need the vector order to
     // provide priorities
